@@ -30,7 +30,7 @@
 #include "tree.h"
 #include "../vfs/vfs.h"
 
-/* "$Id: dir.c,v 1.19 1999/08/27 05:01:10 unammx Exp $" */
+/* "$Id: dir.c,v 1.20 1999/11/03 12:50:54 pavel Exp $" */
 
 /*
  * If true show files starting with a dot.
@@ -383,7 +383,7 @@ handle_dirent (dir_list *list, char *filter, struct dirent *dp,
     if (!show_backups && dp->d_name [NLENGTH (dp)-1] == '~')
 	return 0;
     if (mc_lstat (dp->d_name, buf1) == -1) {
-	message(1, _(" Error "), _("File exists but can not be stat-ed: %s %s"), dp->d_name, strerror(errno));
+	message(1, _(" Error "), _("File '%s' exists but can not be stat-ed: %s"), dp->d_name, strerror(errno));
         return 0;
     }
 
