@@ -144,7 +144,7 @@
 #include "gsession.h"
 #endif
 
-/* "$Id: main.c,v 1.104 1999/11/11 14:35:40 pavel Exp $" */
+/* "$Id: main.c,v 1.111 2000/02/23 07:43:16 norbert Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -190,8 +190,8 @@ int   mark_moves_down = 1;
 /* If true, at startup the user-menu is invoked */
 int   auto_menu = 0;
 
-/* If true, use + and \ keys normally and select/unselect do if M-+ / M-\ and M--
-   and keypad + / - */
+/* If true, use + and \ keys normally and select/unselect do if M-+ / M-\ 
+   and M-- and keypad + / - */
 int   alternate_plus_minus = 0;
 
 /* If true, then the +, - and \ keys have their special meaning only if the
@@ -328,8 +328,9 @@ char *command_line_colors;
 /* File name to view if argument was supplied */
 char *view_one_file = 0;
 
-/* File name to view if argument was supplied */
+/* File name to edit if argument was supplied */
 char *edit_one_file = 0;
+static int edit_one_file_start_line = 1;
 
 /* Used so that widgets know if they are being destroyed or
    shut down */
@@ -365,7 +366,7 @@ char cmd_buf [512];
 int finish_program = 0;
 
 /* If set, then no windows are displayed in the GNOME edition */
-int   nowindows = 0;
+int   nowindows = 0, nodesktop = 0, twopanel;
 
 /* If set it displays the directory that holds the gnome .links files */
 int display_linksdir = 0;
@@ -446,10 +447,10 @@ update_one_panel_widget (WPanel *panel, int force_update, char *current_file)
     if (force_update & UP_RELOAD){
 	panel->is_panelized = 0;
 
-#if 1
+#if 0
 	ftpfs_flushdir ();
 #endif
-#warning Should supply flushdir method
+/* FIXME: Should supply flushdir method */
 	memset (&(panel->dir_stat), 0, sizeof (panel->dir_stat));
     }
     
@@ -599,9 +600,10 @@ static void parse_control_file (void)
 	return;
     }
 #ifndef OS2_NT
-    /* Security: Check that the user owns the control file to prevent
-       other users from playing tricks on him/her. */
-    if (s.st_uid != getuid ()){
+    /* Security: Check that the user owns the control file and this file 
+       is not group/world writable to prevent other users from playing tricks 
+       on him/her. */
+    if (s.st_uid != getuid () || ((s.st_mode) & (S_IWGRP|S_IWOTH))) {
 	fclose (file);
 	return;
     }
@@ -1172,7 +1174,7 @@ maybe_cd (int char_code, int move_up_dir)
     }
     return 0;
 }
-
+#if 0
 static void
 set_sort_to (WPanel *p, sortfn *sort_order)
 {
@@ -1189,7 +1191,7 @@ set_sort_to (WPanel *p, sortfn *sort_order)
     }
     do_re_sort (p);
 }
-
+#endif
 void
 sort_cmd (void)
 {
@@ -1722,7 +1724,7 @@ init_labels (Widget *paneletc)
     define_label (midnight_dlg, paneletc, 10, _("Quit"), (voidfn) quit_cmd);
 }
 
-static key_map ctl_x_map [] = {
+static const key_map ctl_x_map [] = {
     { XCTRL('c'),   (callfn) quit_cmd },
 #ifdef USE_VFS
     { 'a',          reselect_vfs },
@@ -1770,7 +1772,7 @@ static void nothing ()
 {
 }
 
-static key_map default_map [] = {
+static const key_map default_map [] = {
 #ifndef HAVE_GNOME
     { KEY_F(19),  menu_last_selected_cmd },
     { KEY_F(20),  (key_callback) quiet_quit_cmd },
@@ -2212,26 +2214,24 @@ mc_maybe_editor_or_viewer (void)
 	    setup_dummy_mc (path);
 	    view_file (path, 0, 1);
     }
-#ifdef USE_INTERNAL_EDIT
     else {
 	    path = prepend_cwd_on_local ("");
 #ifndef HAVE_GNOME
 	    setup_dummy_mc (path);
 #endif
-	    edit (edit_one_file, 1);
+	    edit (edit_one_file, edit_one_file_start_line);
 #ifdef HAVE_GNOME
 	    gtk_main ();
 	    exit (1);
 #endif
     }
-#endif
     g_free (path);
     midnight_shutdown = 1;
     done_mc ();
     return 1;
 }
 
-#endif
+#endif	/* USE_INTERNAL_EDIT */
 
 static void
 do_nc (void)
@@ -2284,8 +2284,8 @@ version (int verbose)
 	    _("with mouse support on xterm%s.\n"),
 	     status_mouse_support ? _(" and the Linux console") : "");
 #endif /* HAVE_X */
-
-    fprintf (stderr, features);
+    for (verbose = 0; features [verbose]; verbose++) 
+    	fprintf (stderr, _(features [verbose]));
     if (print_last_wd)
 	write (stdout_fd, ".", 1);
 }
@@ -2481,63 +2481,69 @@ init_sigchld (void)
 static void
 print_mc_usage (void)
 {
-    version (0);
-    fprintf (stderr,
-	"Usage is:\n\n"
-        "mc [flags] [this_dir] [other_panel_dir]\n\n"	
+    const char * const * ptr;
+    const char * const usage [] = {
+	    
+    N_("Usage is:\n\n"
+       "mc [flags] [this_dir] [other_panel_dir]\n\n"),
 #if defined(HAVE_SLANG) && !defined(OS2_NT)
-    "-a, --stickchars   Force use of +, -, | for line drawing.\n"
+    N_("-a, --stickchars   Force use of +, -, | for line drawing.\n"),
 #endif
-    "-b, --nocolor      Force black and white display.\n"
+    N_("-b, --nocolor      Force black and white display.\n"),
 #ifdef WITH_BACKGROUND
-    "-B, --background   [DEVEL-ONLY: Debug the background code]\n"
+    N_("-B, --background   [DEVEL-ONLY: Debug the background code]\n"),
 #endif
-    "-c, --color        Force color mode.\n"
-    "-C, --colors       Specify colors (use --help-colors to get a list).\n"
-    "-d, --nomouse      Disable mouse support.\n"
+    N_("-c, --color        Force color mode.\n"
+       "-C, --colors       Specify colors (use --help-colors to get a list).\n"
+       "-d, --nomouse      Disable mouse support.\n"),
 #ifdef USE_INTERNAL_EDIT
-    "-e, --edit         Startup the internal editor.\n"
+    N_("-e, --edit         Startup the internal editor.\n"),
 #endif
-    "-f, --libdir       Print configured paths.\n"
-    "-h, --help         Shows this help message.\n"
-    "-k, --resetsoft    Reset softkeys (HP terminals only) to their terminfo/termcap\n"
-    "                   default.\n"
+    N_("-f, --libdir       Print configured paths.\n"
+       "-h, --help         Shows this help message.\n"
+       "-k, --resetsoft    Reset softkeys (HP terminals only) to their terminfo/termcap\n"
+       "                   default.\n"),
 #ifdef USE_NETCODE
-    "-l, --ftplog file  Log ftpfs commands to the file.\n"
+    N_("-l, --ftplog file  Log ftpfs commands to the file.\n"),
 #endif
 #ifdef HAVE_MAD
-    "-M, --memory file  [DEVEL-ONLY: Log MAD messages to the file.]\n"
+    N_("-M, --memory file  [DEVEL-ONLY: Log MAD messages to the file.]\n"),
 #endif
-    "-P, --printwd      At exit, print the last working directory.\n"
-    "-s, --slow         Disables verbose operation (for slow terminals).\n"
+    N_("-P, --printwd      At exit, print the last working directory.\n"
+       "-s, --slow         Disables verbose operation (for slow terminals).\n"),
 #if defined(HAVE_SLANG) && !defined(OS2_NT)
-    "-t, --termcap      Activate support for the TERMCAP variable.\n"
+    N_("-t, --termcap      Activate support for the TERMCAP variable.\n"),
 #endif
 #if defined(HAVE_SLANG) && defined(OS2_NT)
-    "-S, --createcmdile Create command file to set default directory upon exit.\n"
+    N_("-S, --createcmdile Create command file to set default directory upon exit.\n"),
 #endif
-		 
 #ifdef HAVE_SUBSHELL_SUPPORT
-    "-u, --nosubshell   Disable the concurrent subshell mode.\n"
-    "-U, --subshell     Force the concurrent subshell mode.\n"
-    "-r, --forceexec    Force subshell execution.\n"
+    N_("-u, --nosubshell   Disable the concurrent subshell mode.\n"
+       "-U, --subshell     Force the concurrent subshell mode.\n"
+       "-r, --forceexec    Force subshell execution.\n"),
 #endif
-    "-v, --view fname   Start up into the viewer mode.\n"
-    "-V, --version      Report version and configuration options.\n"
-    "-x, --xterm        Force xterm mouse support and screen save/restore.\n"
+    N_("-v, --view fname   Start up into the viewer mode.\n"
+       "-V, --version      Report version and configuration options.\n"
+       "-x, --xterm        Force xterm mouse support and screen save/restore.\n"),
 #ifdef HAVE_SUBSHELL_SUPPORT
-    "-X, --dbgsubshell  [DEVEL-ONLY: Debug the subshell].\n"
+    N_("-X, --dbgsubshell  [DEVEL-ONLY: Debug the subshell].\n"),
 #endif
-    "\n"
-    "Please send any bug reports (including the output of `mc -V')\n"
-    "to mc-bugs@nuclecu.unam.mx\n"
-    );
+    N_("\n"
+       "Please send any bug reports (including the output of `mc -V')\n"
+       "to mc-bugs@nuclecu.unam.mx\n"),
+    NULL    
+    };
+
+    version (0);
+    
+    for (ptr = usage; *ptr; ptr++)
+	fprintf (stderr, _(*ptr));
 }
 
 static void
 print_color_usage (void)
 {
-    fprintf (stderr,
+    fprintf (stderr, _(
 	     "--colors KEYWORD={FORE},{BACK}\n\n"
 	     "{FORE} and {BACK} can be ommited, and the default will be used\n"
 	     "\n"
@@ -2552,11 +2558,9 @@ print_color_usage (void)
 	     "Colors:\n"
 	     "   black, gray, red, brightred, green, brightgreen, brown,\n"
 	     "   yellow, blue, brightblue, magenta, brightmagenta, cyan,\n"
-	     "   brightcyan, lightgray and white\n\n");
-
+	     "   brightcyan, lightgray and white\n\n"));
 }
 
-
 static void
 probably_finish_program (void)
 {
@@ -2674,7 +2678,7 @@ static void parse_an_arg (poptContext state,
 
 char *cmdline_geometry = NULL;
 
-static struct poptOption argument_table [] = {
+static const struct poptOption argument_table [] = {
 #ifdef HAVE_GNOME
 	{ NULL, '\0', POPT_ARG_CALLBACK, parse_an_arg, 0},
 #endif
@@ -2749,6 +2753,8 @@ static struct poptOption argument_table [] = {
 #ifdef HAVE_GNOME
     { "geometry", '\0', POPT_ARG_STRING, &cmdline_geometry, 0, N_("Geometry for the window"), N_("GEOMETRY")},
     {"nowindows", '\0', POPT_ARG_NONE, &nowindows, 0, N_("No windows opened at startup"), NULL},
+    {"nodesktop", '\0', POPT_ARG_NONE, &nodesktop, 0, N_("No desktop icons"), NULL},
+    {"twopanel", '\0', POPT_ARG_NONE, &twopanel, 0, N_("Look more like traditional gmc"), NULL},
     {"desktop-linksdir", '\0', POPT_ARG_NONE, &display_linksdir, 0,
      N_("Display the directory that holds the .links startup files and exit")},
 #endif
@@ -2756,6 +2762,7 @@ static struct poptOption argument_table [] = {
     { NULL, 		0,			0, NULL, 0 }
 };
 
+#if defined(HAVE_CORBA) || defined(HAVE_GNOME)
 /* Convenience function to display the desktop initialization directory and exit */
 static void
 maybe_display_linksdir (void)
@@ -2765,6 +2772,7 @@ maybe_display_linksdir (void)
 		exit (1);
 	}
 }
+#endif
 
 #ifdef HAVE_CORBA
 /* Initializes the ORB and does the initial argument processing */
@@ -2870,12 +2878,24 @@ handle_args (int argc, char *argv [])
     base = x_basename (argv[0]);
     if (!STRNCOMP (base, "mce", 3) || !STRCOMP(base, "vi")) {
 	edit_one_file = "";
-        if (tmp)
+	edit_one_file_start_line = 1;
+        if (tmp) {
+	    if (*tmp == '+' && isdigit (tmp[1])){
+		int start_line = atoi (tmp);
+		if (start_line > 0) {
+		    char *file = poptGetArg (ctx);
+		    if (file) {
+			tmp = file;
+			edit_one_file_start_line = start_line;
+		    }
+		}
+	    }
 	    edit_one_file = g_strdup (tmp);
+	}
     } else
-	if (!STRNCOMP (base, "mcv", 3) || !STRCOMP(base, "view")) {
-	    if (tmp)
-		view_one_file = g_strdup (tmp);
+    if (!STRNCOMP (base, "mcv", 3) || !STRCOMP(base, "view")) {
+	if (tmp)
+	    view_one_file = g_strdup (tmp);
     } else {
        	/* sets the current dir and the other dir */
 	if (tmp) {
@@ -2997,7 +3017,7 @@ main (int argc, char *argv [])
 	if (base){
 	    if (strcmp (base, "mcedit") == 0)
 		edit_one_file = "";
-	    
+	    else
 	    if (strcmp (base, "mcview") == 0)
 		view_one_file = "";
 	}
