@@ -3,6 +3,8 @@
  *
  * Written at 1998 by Pavel Machek <pavel@ucw.cz>, distribute under LGPL.
  *
+ * $Id: direntry.c,v 1.27 2000/01/31 13:48:00 pavel Exp $
+ *
  * Very loosely based on tar.c from midnight and archives.[ch] from
  * avfs by Miklos Szeredi (mszeredi@inf.bme.hu)
  *
@@ -41,7 +43,6 @@ vfs_s_new_inode (vfs *me, vfs_s_super *super, struct stat *initstat)
     if (!ino)
 	return NULL;
 
-
     ino->linkname = ino->localname = NULL;
     ino->subdir = NULL;
     if (initstat)
@@ -191,7 +192,6 @@ struct vfs_s_entry *
 vfs_s_generate_entry (vfs *me, char *name, struct vfs_s_inode *parent, mode_t mode)
 {
     struct vfs_s_inode *inode;
-    struct vfs_s_entry *entry;
     struct stat *st;
 
     st = vfs_s_default_stat (me, mode);
@@ -199,9 +199,7 @@ vfs_s_generate_entry (vfs *me, char *name, struct vfs_s_inode *parent, mode_t mo
     if (S_ISDIR (mode))
         vfs_s_add_dots (me, inode, parent);
 
-    entry = vfs_s_new_entry (me, name, inode);
-
-    return entry;
+    return vfs_s_new_entry (me, name, inode);
 }
 
 /* We were asked to create entries automagically */
@@ -298,13 +296,11 @@ vfs_s_find_entry_linear (vfs *me, vfs_s_inode *root, char *path, int follow, int
     if (!(flags & FL_DIR)){
 	char *dirname, *name, *save;
 	vfs_s_inode *ino;
-	vfs_s_entry *ent;
 	split_dir_name (me, path, &dirname, &name, &save);
 	ino = vfs_s_find_inode (me, root, dirname, follow, flags | FL_DIR);
 	if (save)
 	    *save = PATH_SEP;
-	ent = vfs_s_find_entry_tree (me, ino, name, follow, flags);
-	return ent;
+	return vfs_s_find_entry_tree (me, ino, name, follow, flags);
     }
 
     for (ent = root->subdir; ent != NULL; ent = ent->next)
@@ -313,8 +309,7 @@ vfs_s_find_entry_linear (vfs *me, vfs_s_inode *root, char *path, int follow, int
 
     if (ent && (! (MEDATA->dir_uptodate) (me, ent->ino))){
 #if 1
-	print_vfs_message ("Dir cache expired for %s", path);
-	sleep(1);
+	print_vfs_message (_("Dir cache expired for %s"), path);
 #endif
 	vfs_s_free_entry (me, ent);
 	ent = NULL;
@@ -374,6 +369,9 @@ vfs_s_resolve_symlink (vfs *me, vfs_s_entry *entry, char *path, int follow)
 
     linkname = entry->ino->linkname;
 
+    if (linkname == NULL)
+	ERRNOR (EFAULT, NULL);
+
     if (MEDATA->find_entry == vfs_s_find_entry_linear) {
         if (*linkname == PATH_SEP)
 	    return (MEDATA->find_entry) (me, entry->dir->super->root, linkname, follow - 1, 0);
@@ -440,13 +438,13 @@ vfs_s_free_super (vfs *me, vfs_s_super *super)
 	super->root = NULL;
     }
 
-#if 1
-    /* We currently leak small ammount of memory, sometimes. Fix it if you can. */
+#if 0
+    /* FIXME: We currently leak small ammount of memory, sometimes. Fix it if you can. */
     if (super->ino_usage)
-	message_1s1d (1, " Direntry warning ", "Super ino_usage is %d, memory leak", super->ino_usage);
+	message_1s1d (1, _(" Direntry warning "), _("Super ino_usage is %d, memory leak"), super->ino_usage);
 
     if (super->want_stale)
-	message_1s (1, " Direntry warning ", "Super has want_stale set");
+	message_1s (1, _(" Direntry warning "), _("Super has want_stale set"));
 #endif
 
     if (super->prevp){
@@ -534,11 +532,10 @@ vfs_s_get_path (vfs *me, char *inname, struct vfs_s_super **archive, int flags)
 {
     char *buf = g_strdup( inname );
     char *res = vfs_s_get_path_mangle (me, buf, archive, flags);
-    char *res2 = NULL;
     if (res)
-        res2 = g_strdup(res);
+        res = g_strdup(res);
     g_free(buf);
-    return res2;
+    return res;
 }
 
 void
@@ -557,8 +554,6 @@ vfs_s_fullpath (vfs *me, vfs_s_inode *ino)
     if (MEDATA->find_entry != vfs_s_find_entry_linear)
 	vfs_die ("Implement me!");
     if (!ino->ent) /* That must be directory... */
-        
-    if (!ino->ent)
 	ERRNOR (EAGAIN, NULL);
 
     if ((!ino->ent->dir) || (!ino->ent->dir->ent)) /* It must be directory */
@@ -584,16 +579,12 @@ vfs_s_inode *
 vfs_s_inode_from_path (vfs *me, char *name, int flags)
 {
     struct vfs_s_super *super;
-    struct vfs_s_inode *ino;
     char *q;
 
     if (!(q = vfs_s_get_path_mangle (me, name, &super, 0))) 
 	return NULL;
 
-    ino = vfs_s_find_inode (me, super->root, q, flags & FL_FOLLOW ? LINK_FOLLOW : LINK_NO_FOLLOW, flags & ~FL_FOLLOW);
-    if (ino) return ino;
-
-    return ino;
+    return vfs_s_find_inode (me, super->root, q, flags & FL_FOLLOW ? LINK_FOLLOW : LINK_NO_FOLLOW, flags & ~FL_FOLLOW);
 
 }
 
@@ -745,6 +736,10 @@ vfs_s_readlink (vfs *me, char *path, char *buf, int size)
 
     if (!S_ISLNK (ino->st.st_mode))
 	ERRNOR (EINVAL, -1);
+
+    if (ino->linkname == NULL)
+	ERRNOR (EFAULT, -1);
+
     strncpy (buf, ino->linkname, size);
     *(buf+size-1) = 0;
     return strlen (buf);
@@ -823,7 +818,7 @@ vfs_s_read (void *fh, char *buffer, int count)
     vfs *me = FH_SUPER->me;
     
     if (FH->linear == LS_LINEAR_CLOSED){
-        print_vfs_message ("Starting linear transfer...");
+        print_vfs_message (_("Starting linear transfer..."));
 	if (!MEDATA->linear_start (me, FH, 0))
 	    return -1;
     }
@@ -960,15 +955,13 @@ vfs_s_retrieve_file(vfs *me, struct vfs_s_inode *ino)
 
     /* Clear the interrupt status */
     
-    while (1) {
-	n = MEDATA->linear_read (me, &fh, buffer, sizeof(buffer));
+    while ((n = MEDATA->linear_read (me, &fh, buffer, sizeof(buffer)))) {
+
 	if (n < 0)
 	    goto error_1;
-	if (!n)
-	    break;
 
 	total += n;
-	vfs_print_stats (me->name, "Getting file", ino->ent->name, total, stat_size);
+	vfs_print_stats (me->name, _("Getting file"), ino->ent->name, total, stat_size);
 
         if (write(handle, buffer, n) < 0) {
 	    me->verrno = errno;
@@ -1022,20 +1015,16 @@ vfs_s_dump (vfs *me, char *prefix, vfs_s_inode *ino)
     printf ("%s %s %d ", prefix, S_ISDIR (ino->st.st_mode) ? "DIR" : "FILE", ino->st.st_mode);
     if (!ino->subdir)
 	printf ("FILE\n");
-
     else
     {
 	struct vfs_s_entry *ent;
-	ent = ino->subdir;
-	while (ent){
-	    char *s;
-	    s = g_strconcat (prefix, "/", ent->name, NULL);
+	for (ent = ino->subdir; ent ; ent = ent->next){
+	    char *s = g_strconcat (prefix, "/", ent->name, NULL);
 	    if (ent->name[0] == '.')
 		printf ("%s IGNORED\n", s);
 	    else
 		vfs_s_dump (me, s, ent->ino);
 	    g_free(s);
-	    ent = ent->next;
 	}
     }
 }
@@ -1181,7 +1170,7 @@ int
 vfs_s_get_line_interruptible (vfs *me, char *buffer, int size, int fd)
 {
     int n;
-    int i = 0;
+    int i;
 
     enable_interrupt_key ();
     for (i = 0; i < size-1; i++){
