@@ -7,7 +7,7 @@
 	       1997 Norbert Warmuth
 	       1998 Pavel Machek
 
-   $Id: ftpfs.c,v 1.59 2000/02/25 12:53:06 pavel Exp $   
+   $Id: ftpfs.c,v 1.61 2000/04/03 10:35:48 pavel Exp $   
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -56,6 +56,7 @@ What to do with this?
 
 /* Namespace pollution: horrible */
 
+#include <sys/types.h>          /* POSIX-required by sys/socket.h and netdb.h */
 #include <netdb.h>		/* struct hostent */
 #include <sys/socket.h>		/* AF_INET */
 #include <netinet/in.h>		/* struct in_addr */
@@ -1439,7 +1440,6 @@ send_ftp_command(vfs *me, char *filename, char *cmd, int flags)
     if (!(rpath = vfs_s_get_path_mangle(me, filename, &super, 0)))
 	return -1;
     p = translate_path (me, super, rpath);
-    g_free(rpath);
     r = command (me, super, WAIT_REPLY, cmd, p);
     g_free (p);
     vfs_add_noncurrent_stamps (&vfs_ftpfs_ops, (vfsid) super, NULL);
