@@ -10,6 +10,8 @@
    Written by: 1995 Miguel de Icaza.
                1997 Norbert Warmuth.
    
+   $Id: undelfs.c,v 1.12 2000/01/05 14:13:59 pavel Exp $
+ 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
    as published by the Free Software Foundation; either version 2 of
@@ -75,7 +77,7 @@ static struct lsdel_struct     lsd;
 static struct deleted_info     *delarray;
 static int num_delarray, max_delarray;
 static char *block_buf;
-static char *undelfserr = " undelfs: error ";
+static char *undelfserr = N_(" undelfs: error ");
 static int readdir_ptr;
 static int undelfs_usage;
 
@@ -178,27 +180,27 @@ undelfs_loaddel (void)
     num_delarray = 0;
     delarray = g_new (struct deleted_info, max_delarray);
     if (!delarray) {
-	message_1s (1, undelfserr, " not enough memory ");
+	message_1s (1, undelfserr, _(" not enough memory "));
 	return 0;
     }
     block_buf = g_malloc (fs->blocksize * 3);
     if (!block_buf) {
-	message_1s (1, undelfserr, " while allocating block buffer ");
+	message_1s (1, undelfserr, _(" while allocating block buffer "));
 	goto free_delarray;
     }
     if ((retval = ext2fs_open_inode_scan(fs, 0, &scan))){
-	message_1s1d (1, undelfserr, " open_inode_scan: %d ", retval);
+	message_1s1d (1, undelfserr, _(" open_inode_scan: %d "), retval);
 	goto free_block_buf;
     }
     if ((retval = ext2fs_get_next_inode(scan, &ino, &inode))){
-	message_1s1d (1, undelfserr, " while starting inode scan %d ", retval);
+	message_1s1d (1, undelfserr, _(" while starting inode scan %d "), retval);
 	goto error_out;
     }
 
     count = 0;
     while (ino) {
 	if ((count++ % 1024) == 0) 
-	    print_vfs_message ("undelfs: loading deleted files information %d inodes", count);
+	    print_vfs_message (_("undelfs: loading deleted files information %d inodes"), count);
 	if (inode.i_dtime == 0)
 	    goto next;
 
@@ -213,7 +215,7 @@ undelfs_loaddel (void)
 	retval = ext2fs_block_iterate(fs, ino, 0, block_buf,
 				      lsdel_proc, &lsd);
 	if (retval) {
-	    message_1s1d (1, undelfserr, " while calling ext2_block_iterate %d ", retval);
+	    message_1s1d (1, undelfserr, _(" while calling ext2_block_iterate %d "), retval);
 	    goto next;
 	}
 	if (lsd.free_blocks && !lsd.bad_blocks) {
@@ -221,7 +223,7 @@ undelfs_loaddel (void)
 		max_delarray += 50;
 		delarray = g_renew (struct deleted_info, delarray, max_delarray);
 		if (!delarray) {
-		    message_1s (1, undelfserr, " no more memory while reallocating array ");
+		    message_1s (1, undelfserr, _(" no more memory while reallocating array "));
 		    goto error_out;
 		}
 	    }
@@ -240,7 +242,7 @@ undelfs_loaddel (void)
     next:
 	retval = ext2fs_get_next_inode(scan, &ino, &inode);
 	if (retval) {
-	    message_1s1d(1, undelfserr, " while doing inode scan %d ", retval);
+	    message_1s1d(1, undelfserr, _(" while doing inode scan %d "), retval);
 	    goto error_out;
 	}
     }
@@ -264,7 +266,7 @@ void com_err (const char *str, long err_code, const char *s2, ...)
     char *cptr;
 
     cptr = g_strdup_printf (" %s (%s: %ld) ", s2, str, err_code);
-    message_1s (1, " Ext2lib error ", cptr);
+    message_1s (1, _(" Ext2lib error "), cptr);
     g_free (cptr);
 }
 
@@ -291,28 +293,28 @@ undelfs_opendir (vfs *me, char *dirname)
     }
 
     if (ext2fs_open (ext2_fname, 0, 0, 0, unix_io_manager, &fs)){
-	message_2s (1, undelfserr, " Could not open file %s ", ext2_fname);
+	message_2s (1, undelfserr, _(" Could not open file %s "), ext2_fname);
 	return 0;
     }
-    print_vfs_message ("undelfs: reading inode bitmap...");
+    print_vfs_message (_("undelfs: reading inode bitmap..."));
     if (ext2fs_read_inode_bitmap (fs)){
 	message_2s (1, undelfserr,
-		 " Could not load inode bitmap from: \n %s \n", ext2_fname);
+		 _(" Could not load inode bitmap from: \n %s \n"), ext2_fname);
 	goto quit_opendir;
     }
-    print_vfs_message ("undelfs: reading block bitmap...");
+    print_vfs_message (_("undelfs: reading block bitmap..."));
     if (ext2fs_read_block_bitmap (fs)){
 	message_2s (1, undelfserr,
-		 " Could not load block bitmap from: \n %s \n", ext2_fname);
+		 _(" Could not load block bitmap from: \n %s \n"), ext2_fname);
 	goto quit_opendir;
     }
     /* Now load the deleted information */
     if (!undelfs_loaddel ())
 	goto quit_opendir;
-    print_vfs_message ("undelfs: done.");
+    print_vfs_message (_("undelfs: done."));
     return fs;
 quit_opendir:
-    print_vfs_message ("undelfs: failure");
+    print_vfs_message (_("undelfs: failure"));
     ext2fs_close (fs);
     fs = NULL;
     return 0;
@@ -336,8 +338,7 @@ undelfs_readdir (void *vfs_info)
     char *dirent_dest;
     
     if (vfs_info != fs){
-	message_1s (1, " delfs: internal error ",
-		 " vfs_info is not fs! ");
+	message_1s (1, undelfserr, _(" vfs_info is not fs! "));
 	return NULL;
     }
     if (readdir_ptr == num_delarray)
@@ -385,7 +386,7 @@ undelfs_open (vfs *me, char *fname, int flags, int mode)
 {
     char *file, *f;
     ino_t  inode, i;
-    undelfs_file *p;
+    undelfs_file *p = 0;
     
     /* Only allow reads on this file system */
     undelfs_get_path (fname, &file, &f);
@@ -393,7 +394,7 @@ undelfs_open (vfs *me, char *fname, int flags, int mode)
 	return 0;
     
     if (!ext2_fname || strcmp (ext2_fname, file)){
-	message_1s (1, undelfserr, " You have to chdir to extract files first ");
+	message_1s (1, undelfserr, _(" You have to chdir to extract files first "));
 	g_free (file);
 	g_free (f);
 	return 0;
@@ -516,7 +517,7 @@ undelfs_read (void *vfs_info, char *buffer, int count)
     retval = ext2fs_block_iterate(fs, p->inode, 0, NULL,
 				  dump_read, p);
     if (retval){
-	message_1s (1, undelfserr, " while iterating over blocks ");
+	message_1s (1, undelfserr, _(" while iterating over blocks "));
 	return -1;
     }
     if (p->error_code && !p->finished)
@@ -577,7 +578,7 @@ undelfs_lstat(vfs *me, char *path, struct stat *buf)
     }
 	
     if (!ext2_fname || strcmp (ext2_fname, file)){
-	message_1s (1, undelfserr, " You have to chdir to extract files first ");
+	message_1s (1, undelfserr, _(" You have to chdir to extract files first "));
 	g_free (file);
 	g_free (f);
 	return 0;
@@ -621,7 +622,7 @@ undelfs_chdir(vfs *me, char *path)
     /* this could be fixed by making an ext2fs io manager to use */
     /* our vfs, but that is left as an excercise for the reader */
     if ((fd = open (file, O_RDONLY)) == -1){
-	message_2s (1, undelfserr, " Could not open file: %s ", file);
+	message_2s (1, undelfserr, _(" Could not open file: %s "), file);
 	g_free (f);
 	g_free (file);
 	return -1;
@@ -667,14 +668,24 @@ undelfs_free(vfsid id)
     undelfs_shutdown ();
 }
 
+#ifdef	ENABLE_NLS
+static int
+undelfs_init(vfs *me) {
+    undelfserr = _(undelfserr);
+    return 1;
+}
+#else
+#define undelfs_init	NULL
+#endif
+
 vfs vfs_undelfs_ops = {
     NULL,	/* This is place of next pointer */
-    "Undelete filesystem for ext2",
+    N_("Undelete filesystem for ext2"),
     0,	/* flags */
     "undel:",	/* prefix */
     NULL,	/* data */
     0,		/* errno */
-    NULL,
+    undelfs_init,
     NULL,
     NULL,	/* fill_names */
     NULL,
