@@ -127,6 +127,7 @@ struct utimbuf {
     /* Other file systems */
     extern vfs vfs_local_ops;
     extern vfs vfs_tarfs_ops;
+    extern vfs vfs_cpiofs_ops;
 
     extern vfs vfs_ftpfs_ops;
     extern vfs vfs_smbfs_ops;
@@ -156,14 +157,15 @@ struct utimbuf {
     void vfs_rm_parents (struct vfs_stamping *stamp);
     char *vfs_path (char *path);
     char *vfs_strip_suffix_from_filename (char *filename);
-    char *vfs_canon (char *path);
+    char *vfs_canon (const char *path);
     char *mc_get_current_wd (char *buffer, int bufsize);
     int vfs_current_is_local (void);
 #if 0
     int vfs_current_is_extfs (void);
     int vfs_current_is_tarfs (void);
+    int vfs_current_is_cpiofs (void);
 #endif
-    int vfs_file_is_local (char *name);
+    int vfs_file_is_local (const char *name);
     int vfs_file_is_ftp (char *filename);
     int vfs_file_is_smb (char *filename);
     char *vfs_get_current_dir (void);
@@ -192,7 +194,7 @@ struct utimbuf {
     
     /* Only the routines outside of the VFS module need the emulation macros */
 
-	int   mc_open  (char *file, int flags, ...);
+	int   mc_open  (const char *filename, int flags, ...);
 	int   mc_close (int handle);
 	int   mc_read  (int handle, char *buffer, int count);
 	int   mc_write (int hanlde, char *buffer, int count);
@@ -222,8 +224,8 @@ struct utimbuf {
         int mc_rmdir    (char *path);
         int mc_mkdir    (char *path, mode_t mode);
 
-        char *mc_getlocalcopy (char *filename);
-        int mc_ungetlocalcopy (char *filename, char *local, int has_changed);
+        char *mc_getlocalcopy (const char *pathname);
+        int mc_ungetlocalcopy (const char *pathname, char *local, int has_changed);
         char *mc_def_getlocalcopy (vfs *vfs, char *filename);
         int mc_def_ungetlocalcopy (vfs *vfs, char *filename, char *local, int has_changed);
         int mc_ctl (int fd, int ctlop, int arg);
@@ -249,6 +251,7 @@ struct utimbuf {
 #   define vfs_file_is_ftp(x) 0
 #   define vfs_file_is_smb(x) 0
 #   define vfs_current_is_tarfs() 0
+#   define vfs_current_is_cpiofs() 0
 #   define vfs_current_is_extfs() 0
 #   define vfs_path(x) x
 #   define vfs_strip_suffix_from_filename(x) g_strdup(x)
@@ -378,7 +381,9 @@ extern void mc_vfs_done( void );
    listed above and O_APPEND */
 
 #if (O_ALL & O_APPEND)
+#ifdef __GNUC__
 #warning Unexpected problem with flags, O_LINEAR disabled, contact pavel@ucw.cz
+#endif
 #define O_LINEAR 0
 #define IS_LINEAR(a) 0
 #define NO_LINEAR(a) a
