@@ -1,6 +1,8 @@
 #ifndef DIRENTRY_H
 #define DIRENTRY_H
 
+/* $Id: xdirentry.h,v 1.11 2000/02/25 12:53:07 pavel Exp $ */
+
 #include <config.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -57,6 +59,9 @@ typedef struct vfs_s_inode {
 	struct {
 	    long data_offset;
 	} tar;
+	struct {
+	    long offset;
+	} cpio;
 	struct {
 	    struct timeval timestamp;
 	    struct stat local_stat;
@@ -114,6 +119,13 @@ typedef struct vfs_s_super {
 #define RFC_DARING 1
 #define RFC_STRICT 2
 	} ftp;
+	struct {
+	    int fd;
+	    struct stat stat;
+	    int type; /* Type of the archive */
+	  /*int pos;    In case reentrancy will be needed */
+	    struct defer_inode *defered; /* List of inodes for which another entries may appear */
+	} cpio;
     } u;
     int magic;
 #define SUPER_MAGIC 0x915ac312
@@ -240,6 +252,9 @@ int vfs_s_select_on_two (int fd1, int fd2);
 int vfs_s_get_line (vfs *me, int sock, char *buf, int buf_len, char term);
 int vfs_s_get_line_interruptible (vfs *me, char *buffer, int size, int fd);
 
+/* misc */
+int vfs_s_retrieve_file (vfs *me, struct vfs_s_inode *ino);
+
 /* If non-null, FREE */
 #define ifree(ptr) do { if (ptr) g_free(ptr); } while (0)
 
